@@ -197,6 +197,23 @@ class DaplaDocumentationMagics(Magics):
                     key
                 )
 
+    def get_input(self, line):
+        opts, args = self.parse_options(line, 'f:', 'nofile')
+        if not args:
+            raise UsageError('Missing variable name.')
+        fname = opts.get('f')
+        if not fname:
+            fname = 'metadoc_{}.json'.format(args)  # add default json file if missing
+        use_file_storage = 'nofile' not in opts
+        try:
+            ds = self.shell.user_ns[args]
+            if not isinstance(ds, DataFrame):
+                raise UsageError("The variable '{}' is not a pyspark DataFrame".format(args))
+        except KeyError:
+            raise UsageError("Could not find dataset '{}'".format(args))
+        dataset_path = self.get_dataset_path(args)
+        return ds, fname, use_file_storage, dataset_path
+
     @line_magic
     def document(self, line):
         """This line magic assists creating documentation metadata for a given variable_name. The variable_name must be
@@ -212,25 +229,9 @@ class DaplaDocumentationMagics(Magics):
         """
         self._result_status = ''  # clear status
 
-        opts, args = self.parse_options(line, 'f:', 'nofile')
-        if not args:
-            raise UsageError('Missing variable name.')
-
-        fname = opts.get('f')
-        use_file_storage = 'nofile' not in opts
-
-        try:
-            ds = self.shell.user_ns[args]
-        except KeyError:
-            raise UsageError("Could not find variable name '{}'".format(args))
-
-        if not isinstance(ds, DataFrame):
-            raise UsageError("The variable '{}' is not a pyspark DataFrame".format(args))
+        ds, fname, use_file_storage, dataset_path = self.get_input(line)
 
         if fname is None and use_file_storage:
-            fname = self.shell.ev('input("Enter filename where the documentation should be stored '
-                                  '(leave blank for no file)")')
-            # Update the user input for future use
             if fname == '':
                 use_file_storage = False
                 contents = "%document --nofile {}".format(line)
@@ -240,24 +241,11 @@ class DaplaDocumentationMagics(Magics):
         elif use_file_storage:
             fname = self.ensure_valid_filename(fname)
 
-        if hasattr(ds, 'doc') and ds.doc is not None:
-            try:
-                ans = self.shell.ask_yes_no("The dataset '{}' has already been documented. "
-                                            "Do you want to proceed?".format(args), default='n')
-            except StdinNotImplementedError:
-                # skip execution if this note is run in batch mode
-                ans = False
-
-            if ans is False:
-                self.clear_output()
-                return
-
         self.clear_output()
 
         try:
             if use_file_storage:
                 file_exists = os.path.isfile(fname)
-                dataset_path = self.get_dataset_path(args)
                 if file_exists:
                     with open(fname, 'r') as f:
                         existing_template = json.dumps(json.load(f), indent=2)
@@ -269,7 +257,6 @@ class DaplaDocumentationMagics(Magics):
                         json.dump(ds.doc, f)
             else:
                 # Generate doc from template
-                dataset_path = self.get_dataset_path(args)
                 ds.doc = self._doc_template_provider(ds.schema.json(), False, dataset_path)
 
         except AuthError as err:
@@ -453,9 +440,7 @@ class DaplaDocumentationMagics(Magics):
             'id': 'please-select',
             'name': 'please select'
         })
-        first = 'please-select'  # candidates[0]['id']
-
-        return first
+        return 'please-select'
 
     def create_candidate_selector(self, binding, key):
         component = widgets.Dropdown()
@@ -470,7 +455,6 @@ class DaplaDocumentationMagics(Magics):
         candidates_from_service = self._doc_template_candidates_provider(key)
         if len(candidates_from_service) > 0:
             candidates = candidates_from_service
-            binding_key['candidates'] = candidates
             selected_id = self.check_selected_id(key, candidates, selected_id)
             binding_key['selected-id'] = selected_id
 
